@@ -1,7 +1,7 @@
 use std::error;
 
 use mit_commit::CommitMessageError;
-use mit_commit_message_lints::{external, lints::Error as LintsError};
+use mit_commit_message_lints::{external, lints::ReadFromTomlOrElseVcsError};
 use thiserror::Error;
 
 #[derive(Error, Debug)]
@@ -11,12 +11,14 @@ pub(crate) enum MitCommitMsgError {
     #[error("failed to read git config from `{0}`: {1}")]
     Io(String, String),
     #[error("{0}")]
-    MitCommitMessageLint(#[from] LintsError),
+    MitCommitMessageLint(#[from] mit_lint::Error),
     #[error("{0}")]
     MitCommitMessage(#[from] CommitMessageError),
     #[error("{0}")]
     External(#[from] external::Error),
     #[error("{0}")]
+    ReadFromTomlOrElseVcs(#[from] ReadFromTomlOrElseVcsError),
+    #[error("{0}")]
     Clipboard(#[from] Box<dyn error::Error + Sync + Send>),
 }
 
